@@ -11,8 +11,8 @@ sql_vars={
     "__username__":"",
     "__password__": "",
     "__cursor__":None,
-    "__host__": "",
-    "__port__": "",
+    "__host__": "45.79.130.8",
+    "__port__": 14096,
     "__database__":"Sun"
 
 }
@@ -33,11 +33,13 @@ elastic_vars = {
 
 ############ 0 LOGGING #############
 def set_elastic_vars(__ip__=None, __port__=None, __user__= None, __password__= None):
-    """[summary]
+    """Set the variables used for ElasticSearch connection
 
     Args:
-        username (str, optional): [description]. Defaults to "sophia2api".
-        password (str, optional): [description]. Defaults to "".
+        __ip__ (int, optional): [ElasticSearch host ip]. Defaults to "None".
+        __port__ (int, optional): [ElasticSearch port]. Defaults to "None".
+        __user__ (str, optional): [ElastichSearch username]. Defaults to "None".
+        __password__ (str, optional): [ElasticSearch password]. Defaults to "None".
     """
     arguments=locals()
     has_changed=False
@@ -53,8 +55,8 @@ def set_elastic_vars(__ip__=None, __port__=None, __user__= None, __password__= N
                                                           elastic_vars["__password__"]))
     return 1
 
-def login(__username__="", __password__="", __host__="45.56.109.120", __port__=14096, __database__="Sun"):
-    """[summary]
+def login(__username__="", __password__="", __host__=None, __port__=None, __database__=None): #45.79.130.8 #45.56.109.120
+    """login into Sun database through a mariadb sql adapter.
 
     Args:
         __username__ (str, optional): [description]. Defaults to "sophia2api".
@@ -73,9 +75,9 @@ def login(__username__="", __password__="", __host__="45.56.109.120", __port__=1
     return connect_sun()
 
 def connect_sun():
-    """[summary]
+    """connect to sun
     Returns:
-        [type]: [description]
+        
     """
     global sql_vars
     try:
@@ -98,7 +100,7 @@ def __connection_validator():
 ############ 1 INFO #############
 
 def list_countries():
-    """provides a list with all the countries that currently have media outlets in Sun
+    """provides a list with all the countries that currently have media outlets in Sun.
 
     Returns:
         [string]: [country_name]
@@ -108,6 +110,11 @@ def list_countries():
     return [x[0] for x in sql_vars["__cursor__"].fetchall()]
 
 def list_media_outlets(countries=["all"]): 
+    """provides a list with all media outlets that currently have media outlets in Sun.
+
+    Returns:
+        [string]: [media_outlet]
+    """
     pd.set_option("display.max_rows",None)
     __connection_validator()
     if "all" in countries: countries=list_countries()
@@ -120,32 +127,44 @@ def list_media_outlets(countries=["all"]):
 
 
 def stats_countries():
+    """Provides a list the countries and it's news quantity in Sun.
+
+    Returns:
+        df: country;news_quantity
+    """
     __connection_validator()
     sql_vars["__cursor__"].execute("SELECT country, count(id) FROM news GROUP BY country")
     return pd.DataFrame(sql_vars["__cursor__"].fetchall(),columns=["country", "quantity"])
     
 
 def stats_countries_by_date(_from, _to):
+    """Provides a list the countries and it's news quantity between a date.
+    
+     Args:
+        __from (string, required): [ElasticSearch host ip]. It must be passed as a string with the following format: YYYY/MM/DD.
+        __to (string, required): [ElasticSearch host ip]. It must be passed as a string with the following format: YYYY/MM/DD.
+        
+    Returns:
+        df: country;news_quantity
+    """
     __connection_validator()
     sql_vars["__cursor__"].execute("SELECT country, count(id) FROM news WHERE date >= ? AND date <= ? GROUP BY country",(_from,_to))
     return pd.DataFrame(sql_vars["__cursor__"].fetchall(),columns=["country", "quantity"])
     
 
-def stats_media_outlet():
+def stats_media_outlet(country=None):
+    """Provides a list the media outlets and it's news quantity in Sun.
+        country (string, optional): country name.
+
+    Returns:
+        df: media_outlet;news_quantity
+    """
     pd.set_option("display.max_rows",None)
     __connection_validator()
-    sql_vars["__cursor__"].execute("SELECT country, media_outlet, count(id) FROM news GROUP BY media_outlet")
-    return pd.DataFrame(sql_vars["__cursor__"].fetchall(),columns=["country", "media_outlet_name", "quantity"])
-
-def stats_media_outlet_by_country(country='chile'):
-    pd.set_option("display.max_rows",None)
-    __connection_validator()
-    sql_vars["__cursor__"].execute("SELECT country, media_outlet, count(id) FROM news WHERE country = ? GROUP BY media_outlet",(country,))
-    return pd.DataFrame(sql_vars["__cursor__"].fetchall(),columns=["country", "media_outlet_name", "quantity"])
-
-def stats_media_outlet_by_country_by_date(country='chile'): #por desarrollar
-    __connection_validator()
-    sql_vars["__cursor__"].execute("SELECT country, media_outlet, count(id) FROM news WHERE country = ? GROUP BY media_outlet",(country,))
+    if country is not None:
+        sql_vars["__cursor__"].execute("SELECT country, media_outlet, count(id) FROM news WHERE country = ? GROUP BY media_outlet",(country,))
+    else:
+        sql_vars["__cursor__"].execute("SELECT country, media_outlet, count(id) FROM news GROUP BY media_outlet")
     return pd.DataFrame(sql_vars["__cursor__"].fetchall(),columns=["country", "media_outlet_name", "quantity"])
 
 
@@ -234,27 +253,5 @@ def export_to_csv(df, name="default"):
     df.to_csv(name,sep=";")
     print("dataset saved as"+name+".csv")
     
-    
-    
-    
-    
-'''def dataset_by_country(country, _from, _to):
-    __connection_validator()
-    sql_vars["__cursor__"].execute("SELECT *, month(date) as month FROM news WHERE date >= ? AND date <= ? AND country = ?", (_from, _to, country))
-    sophia_dataframe= pd.DataFrame(sql_vars["__cursor__"].fetchall(), columns=columns)
-    to_return=sophia_dataframe.astype({"year": "Int64"})
-    del sophia_dataframe
-    return to_return 
+## FUNCIONES CASO DE USO 3
 
-def load_dataset():
-		data = {'id':[1,2], 
-                'country':['chile','france'],
-'media_outlet':['latercera','mediapart'], 'url':['www','www'], 
-'title':['un titulo','un titre'], 
-'text':['un texto','un texte'], 
-'date':['2020-01-01','2020-01-02']}
-		df = pd.DataFrame(data=data)
-		return df
-'''
-#save on js? as parameter of load or another function especially for download?
-#if __username__ is None: set_credentials()
\ No newline at end of file
